package com.diagbot.facade;

import com.diagbot.dto.QuestionDTO;
import com.diagbot.entity.QuestionDetail;
import com.diagbot.entity.QuestionInfo;
import com.diagbot.entity.wrapper.QuestionInfoWrapper;
import com.diagbot.service.impl.QuestionInfoServiceImpl;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.ListUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.QuestionIdsVO;
import com.diagbot.vo.QuestionVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description: 标签业务层
 * @author: zhoutg
 * @time: 2018/8/6 9:11
 */
@Component
public class QuestionFacade extends QuestionInfoServiceImpl {

    @Autowired
    QuestionDetailFacade questionDetailFacade;

    /**
     * 根据参数返回标签内容
     *
     * @param questionVO 获取标签内容参数
     * @return 标签内容
     */
    public QuestionDTO getById(QuestionVO questionVO) {
        Map paramMap = new HashMap<>();
        paramMap.put("sexType", questionVO.getSexType());
        paramMap.put("age", questionVO.getAge());
        paramMap.put("id", questionVO.getId());
        QuestionInfo questionInfo = this.getByParam(paramMap);
        if(questionInfo == null) { //无数据直接返回，不通过报错的形式返回
            return null;
        }
        QuestionDTO res = new QuestionDTO();
        BeanUtil.copyProperties(questionInfo, res);

        //获取明细项
        List<QuestionDetail> questionDetailList = questionDetailFacade.getByQuestionId(questionVO.getId());
        res.setQuestionDetailList(questionDetailList);

        //获取子标签
        List<QuestionInfoWrapper> questionMapping = this.getByQuestionMapping(paramMap);
        List<QuestionDTO> sonQuestionList = BeanUtil.listCopyTo(questionMapping, QuestionDTO.class);
        res.setQuestionMapping(sonQuestionList);
        //获取子标签的明细项
        if(ListUtil.isNotEmpty(sonQuestionList)) {
            Map paramMap1 = new HashMap<>();
            paramMap1.put("sexType", questionVO.getSexType());
            paramMap1.put("age", questionVO.getAge());

            for(QuestionDTO bean : sonQuestionList) {
                List<QuestionDetail> questionDetailList1 = questionDetailFacade.getByQuestionId(bean.getId());
                bean.setQuestionDetailList(questionDetailList1);
                paramMap1.put("id", bean.getId());
                //获取第二级子标签
                List<QuestionInfoWrapper> questionMapping1 = this.getByQuestionMapping(paramMap1);
                List<QuestionDTO> sonQuestionList1 = BeanUtil.listCopyTo(questionMapping1, QuestionDTO.class);
                bean.setQuestionMapping(sonQuestionList1);

                for(QuestionDTO questionDTO : sonQuestionList1) {
                    //获取二级子明细项
                    List<QuestionDetail> questionDetailList2 = questionDetailFacade.getByQuestionId(questionDTO.getId());
                    questionDTO.setQuestionDetailList(questionDetailList2);
                }

            }
        }
        return res;
    }



    /**
     * 查询多个id返回标签内容
     *
     * @param questionIdsVO 获取标签内容参数
     * @return 标签内容
     */
    public Map<Long, Object> getByIds(QuestionIdsVO questionIdsVO) {
        Map<Long, Object> data = new HashMap<>();
        if(StringUtil.isEmpty(questionIdsVO.getIds())) {
            return data;
        }
        String[] ids = questionIdsVO.getIds().split(",");
        for(String id : ids) {
            QuestionVO questionVO = new QuestionVO();
            questionVO.setId(Long.parseLong(id));
            questionVO.setAge(questionIdsVO.getAge());
            questionVO.setSexType(questionIdsVO.getAge());
            QuestionDTO item = this.getById(questionVO);
            data.put(item.getId(), item);
        }
        return data;
    }
}
