package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.entity.DeptVital;
import com.diagbot.entity.QuestionInfo;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.enums.QuestionTypeEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.DeptVitalServiceImpl;
import com.diagbot.util.EntityUtil;
import com.diagbot.vo.DeptVitalVO;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2018/11/22 11:45
 */
@Component
public class DeptVitalFacade extends DeptVitalServiceImpl {

    @Autowired
    private QuestionInfoFacade questionInfoFacade;

    /**
     * 保存查体模板
     *
     * @param deptVitalVO
     * @return
     */
    public Boolean saveDeptVitals(DeptVitalVO deptVitalVO) {
        //先删除该科室原有模板
        QueryWrapper<DeptVital> deptVitalQueryWrapper = new QueryWrapper<DeptVital>();
        deptVitalQueryWrapper.eq("dept_id", deptVitalVO.getDeptId());
        this.remove(deptVitalQueryWrapper);

        //查找标签是否存在
        QueryWrapper<QuestionInfo> questionInfoQueryWrapper = new QueryWrapper<>();
        questionInfoQueryWrapper.in("id", deptVitalVO.getVitalIds()).
                eq("type", QuestionTypeEnum.Vital.getKey()).
                eq("is_deleted", IsDeleteEnum.N.getKey());
        List<QuestionInfo> questionInfoList = questionInfoFacade.list(questionInfoQueryWrapper);

        Map<Long, QuestionInfo> questionInfoMap = EntityUtil.makeEntityMap(questionInfoList, "id");
        for (Long vital : deptVitalVO.getVitalIds()) {
            if (questionInfoMap.get(vital) == null) {
                throw new CommonException(CommonErrorCode.NOT_EXISTS, "id=" + vital + "的查体标签不存在");
            }
        }

        //插入新模板
        List<DeptVital> deptVitalList = Lists.newArrayList();
        for (Long vital : deptVitalVO.getVitalIds()) {
            DeptVital deptVital = new DeptVital();
            deptVital.setDeptId(deptVitalVO.getDeptId());
            deptVital.setVitalId(vital);
            deptVital.setGmtCreate(new Date());
        }
        this.saveBatch(deptVitalList);
        return true;
    }
}
