package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.diagbot.entity.IntroduceDetail;
import com.diagbot.entity.IntroduceInfo;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.service.impl.IntroduceInfoServiceImpl;
import com.diagbot.util.UserUtils;
import com.diagbot.vo.IntroducePageVO;
import com.diagbot.vo.IntroduceVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.Date;
import java.util.Map;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2018/11/16 14:30
 */
@Component
public class IntroduceInfoFacade extends IntroduceInfoServiceImpl {
    @Autowired
    IntroduceMapFacade introduceMapFacade;
    @Autowired
    IntroduceDetailFacade introduceDetailFacade;

    /**
     * 保存提示信息（新增or修改）
     *
     * @param introduceVO
     * @return
     */
    public Boolean saveIntroduce(IntroduceVO introduceVO) {
        IntroduceInfo introduceInfo = new IntroduceInfo();
        if (!(introduceVO.getId() == null)) {
            introduceInfo = this.getById(introduceVO.getId());
            introduceInfo.setModifier(UserUtils.getCurrentPrincipleID());
            introduceInfo.setGmtModified(new Date());
        } else {
            introduceInfo.setCreator(UserUtils.getCurrentPrincipleID());
            introduceInfo.setGmtCreate(new Date());
        }
        introduceInfo.setName(introduceVO.getName());
        introduceInfo.setRemark(introduceVO.getRemark());

        //明细信息不更新，每次都删除重新插入
        //删除已有明细，物理删除
        if (!(introduceInfo.getId() == null)) {
            QueryWrapper<IntroduceDetail> detailQueryWrapper = new QueryWrapper<>();
            detailQueryWrapper.eq("introduce_id", introduceInfo.getId());
            introduceDetailFacade.remove(detailQueryWrapper);
        }
        //新增明细，清空id
        for (IntroduceDetail detail : introduceVO.getDetailList()) {
            detail.setId(null);
        }
        //插入新的明细记录
        introduceDetailFacade.saveOrUpdateBatch(introduceVO.getDetailList());

        //更新提示信息
        this.saveOrUpdate(introduceInfo);
        return true;
    }

    /**
     * 单条删除提示信息 物理删除
     *
     * @param id
     * @return
     */
    public Boolean deleteRecord(Long id) {
        //删除明细
        QueryWrapper<IntroduceDetail> introduceDetailQueryWrapper = new QueryWrapper<>();
        introduceDetailQueryWrapper.eq("introduce_id", id);
        introduceDetailFacade.remove(introduceDetailQueryWrapper);
        this.removeById(id);
        return true;
    }

    /**
     * 批量删除提示信息 物理删除
     *
     * @param ids
     * @return
     */
    public Boolean deleteRecords(Long[] ids) {
        //删除明细
        QueryWrapper<IntroduceDetail> introduceDetailQueryWrapper = new QueryWrapper<>();
        introduceDetailQueryWrapper.in("introduce_id", ids);
        introduceDetailFacade.remove(introduceDetailQueryWrapper);
        this.removeByIds(Arrays.asList(ids));
        return true;
    }

    /**
     * 分页查询提示信息，可带等于条件
     *
     * @param introducePageVO
     * @return
     */
    public IPage<IntroduceInfo> getPageByMap(IntroducePageVO introducePageVO) {
        QueryWrapper<IntroduceInfo> introduceInfoQueryWrapper = new QueryWrapper<>();
        for (Map.Entry<String, Object> entry : introducePageVO.getMap().entrySet()) {
            introduceInfoQueryWrapper.eq(entry.getKey(), entry.getValue());
        }
        IPage<IntroduceInfo> introduceInfoIPage = this.page(introducePageVO, introduceInfoQueryWrapper);
        return introduceInfoIPage;
    }
}
