package com.diagbot.service.impl;

import com.diagbot.client.fastdfs.FastDFSClient;
import com.diagbot.client.fastdfs.FastDFSFile;
import com.diagbot.exception.CommonException;
import com.diagbot.exception.ServiceErrorCode;
import com.diagbot.service.UploadService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.io.InputStream;

/**
 * @Description: 文件上传服务接口实现
 * @author: gaodm
 * @time: 2018/11/13 13:50
 */
@Slf4j
@Service
public class UploadServiceImpl implements UploadService {
    @Override
    public String singleFileUpload(MultipartFile file) {
        String path = "";
        if (file.isEmpty()) {
            throw new CommonException(ServiceErrorCode.FILE_UPLOAD_ERROE, "文件不能为空");
        }
        try {
            // Get the file and save it somewhere
            path = saveFile(file);
        } catch (Exception e) {
            log.error("upload file failed", e);
            throw new CommonException(ServiceErrorCode.FILE_UPLOAD_ERROE, "upload file failed");
        }
        return path;
    }

    /**
     * @param multipartFile
     * @return
     * @throws IOException
     */
    public String saveFile(MultipartFile multipartFile) throws IOException {
        String[] fileAbsolutePath = {};
        String fileName = multipartFile.getOriginalFilename();
        String ext = fileName.substring(fileName.lastIndexOf(".") + 1);
        byte[] file_buff = null;
        InputStream inputStream = multipartFile.getInputStream();
        if (inputStream != null) {
            int len1 = inputStream.available();
            file_buff = new byte[len1];
            inputStream.read(file_buff);
        }
        inputStream.close();
        FastDFSFile file = new FastDFSFile(fileName, file_buff, ext);
        try {
            fileAbsolutePath = FastDFSClient.upload(file);  //upload to fastdfs
        } catch (Exception e) {
            log.error("upload file Exception!", e);
            throw new CommonException(ServiceErrorCode.FILE_UPLOAD_ERROE, "upload file Exception");
        }
        if (fileAbsolutePath == null) {
            log.error("upload file failed,please upload again!");
            throw new CommonException(ServiceErrorCode.FILE_UPLOAD_ERROE, "upload file failed,please upload again");
        }
        String path = "/" + fileAbsolutePath[0] + "/" + fileAbsolutePath[1];
        return path;

    }
}
