package com.diagbot.web;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.IntroduceInfo;
import com.diagbot.facade.IntroduceInfoFacade;
import com.diagbot.vo.IntroducePageVO;
import com.diagbot.vo.IntroduceVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 提示信息 前端控制器
 * </p>
 *
 * @author zhaops
 * @since 2018-11-16
 */
@RestController
@RequestMapping("/introduceInfo")
@Api(value = "提示信息维护相关API", tags = { "提示信息维护相关API" })
public class IntroduceInfoController {

    @Autowired
    IntroduceInfoFacade introduceInfoFacade;

    @ApiOperation(value = "保存提示信息[by:zhaops]",
            notes = "id: 修改时带id,新增时为空<br>" +
                    "name: 名称，必填<br>" +
                    "remark：备注<br>" +
                    "detailList:提示信息明细列表")
    @PostMapping("/saveIntroduce")
    @SysLogger("saveIntroduce")
    public RespDTO<Boolean> saveIntroduce(@RequestBody @Valid IntroduceVO introduceVO) {
        Boolean data = introduceInfoFacade.saveIntroduce(introduceVO);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "单条删除提示信息[by:zhaops]",
            notes = "id: id,必填")
    @PostMapping("/deleteRecord")
    @SysLogger("deleteRecord")
    public RespDTO<Boolean> deleteRecord(@RequestParam Long id) {
        Boolean data = introduceInfoFacade.deleteRecord(id);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "批量删除提示信息[by:zhaops]",
            notes = "ids: ids,必填")
    @PostMapping("/deleteRecords")
    @SysLogger("deleteRecords")
    public RespDTO<Boolean> deleteRecords(@RequestParam Long[] ids) {
        Boolean data = introduceInfoFacade.deleteRecords(ids);
        return RespDTO.onSuc(data);
    }

    /**
     * 分页查询提示信息，可带等于条件
     *
     * @param introducePageVO
     * @return
     */
    @ApiOperation(value = "分页查询提示信息，可带等于条件[by:zhaops]",
            notes = "current:页码，必填<br>" +
                    "size:每页显示条数，必填<br>" +
                    "map:查询条件（=），key为数据库字段名<br>")
    @PostMapping("/getPageByMap")
    @SysLogger("getPageByMap")
    public RespDTO getPageByMap(@RequestBody IntroducePageVO introducePageVO) {
        IPage<IntroduceInfo> infoIPage = introduceInfoFacade.getPageByMap(introducePageVO);
        return RespDTO.onSuc(infoIPage);
    }
}
